@@ -2,15 +2,15 @@ import RPi.GPIO as GPIO
 from time import sleep
 
 # The GPIO pins for the Energenie module
-BIT1 = 11
-BIT2 = 15
-BIT3 = 16
-BIT4 = 13
+BIT1 = 17
+BIT2 = 22
+BIT3 = 23
+BIT4 = 21
 
-ON_OFF_KEY = 18
-ENABLE = 22
+ON_OFF_KEY = 24
+ENABLE = 25
 
-GPIO.setmode(GPIO.BOARD)
+GPIO.setmode(GPIO.BCM)
 GPIO.setwarnings(False)
 
 GPIO.setup(BIT1, GPIO.OUT)
@@ -30,10 +30,11 @@ GPIO.output(BIT3, False)
 GPIO.output(BIT4, False)
 
 # Codes for switching on and off the sockets
-#        all     1       2       3       4
-ON  = ['1011', '1111', '1110', '1101', '1100']
+#       all     1       2       3       4
+ON = ['1011', '1111', '1110', '1101', '1100']
 OFF = ['0011', '0111', '0110', '0101', '0100']
 
+
 def change_plug_state(socket, on_or_off):
     state = on_or_off[socket][3] == '1'
     GPIO.output(BIT1, state)
@@ -48,8 +49,10 @@ def change_plug_state(socket, on_or_off):
     sleep(0.25)
     GPIO.output(ENABLE, False)
 
+
 def switch_on(socket):
     change_plug_state(socket, ON)
 
+
 def switch_off(socket):
     change_plug_state(socket, OFF)
